@@ -19,9 +19,9 @@
 #'
 #' @examples
 #'
-#' ## Get tidy matchup data for Mohamed Elshorbagy vs Karim Abdel Gawad
+#' ## Get tidy matchup data for Mohamed Elshorbagy vs Ali Farag
 #' \donttest{get_matchup(player_1 = "Mohamed Elshorbagy",
-#'                       player_2 = "Karim Abdel Gawad",
+#'                       player_2 = "Ali Farag",
 #'                       category = "mens",
 #'                       tidy = TRUE)}
 #'
@@ -106,7 +106,6 @@ get_matchup <- function(player_1 = NULL, player_2 = NULL, ranks = NULL, category
   ## Clean recent match data and get recent game data
   recent_data <- get_match_game_data(recent_matches, players = players, ranks = ranks)
 
-
   ## Summarize Match Data
   recent_matches <- recent_data$recent_matches %>%
                         rename(player_1_rank = rank,
@@ -440,17 +439,17 @@ get_recent_matches <- function(profile_urls) {
 
 get_match_game_data <- function(data = NULL, players = NULL, ranks = NULL) {
 
-  if (is.null(ranks)) {
+  if (is.null(ranks) & !is.null(players)) {
 
     ## Filter recent_matches by player names
     recent_matches <- data %>%
-      filter(str_detect(.data$player, players[1]) & str_detect(.data$opponent, players[2])) ## Find players in results
+      dplyr::filter(str_detect(.data$player, players[1]) & str_detect(.data$opponent, players[2])) ## Find players in results
 
-  } else if (is.null(players)) {
+  } else if (is.null(players) & !is.null(ranks)) {
 
     ## Filter recent_matches by player ranks
     recent_matches <- data %>%
-      filter(rank %in% ranks[1] & opponent_rank %in% ranks[2])
+      dplyr::filter(rank %in% ranks[1] & opponent_rank %in% ranks[2])
 
   }
 
