@@ -19,6 +19,8 @@ test_that("test get_tournament_games for wrong input errors", {
   expect_error(squashinformr::get_tournament_games(year = 20, world_tour = TRUE))
   ## If negative integer provided to year
   expect_error(squashinformr::get_tournament_games(year = -2020, world_tour = TRUE))
+  ## If querying for more than 6 months of data
+  expect_error(squashinformr::get_tournament_games(tournament = NULL, year = 2021, world_tour = FALSE))
 
 })
 
@@ -41,11 +43,4 @@ test_that("test get_tournament_games for proper outputs", {
   expect_is(sample(df$tournament_date, 1), "Date")
   expect_equal(year(sample(df$tournament_date, 1)), 2021)
 
-  ## All 2020 tournaments
-  df <- squashinformr::get_tournament_games(tournament = NULL, year = 2021, world_tour = FALSE)
-  expect_is(df, "data.frame")
-  expect_is(df, "tbl")
-  expect_is(sample(df$tournament_date, 1), "Date")
-  expect_equal(year(sample(df$tournament_date, 1)), 2021)
-
 })
